@@ -2,7 +2,7 @@ package Crypt::AuthEnc::OCB;
 
 use strict;
 use warnings;
-our $VERSION = '0.047_006';
+our $VERSION = '0.048_001';
 
 use base qw(Crypt::AuthEnc Exporter);
 our %EXPORT_TAGS = ( all => [qw( ocb_encrypt_authenticate ocb_decrypt_verify )] );
@@ -22,7 +22,7 @@ sub ocb_encrypt_authenticate {
   my $plaintext = shift;
 
   my $m = Crypt::AuthEnc::OCB->new($cipher_name, $key, $nonce);
-  $m->aad_add($adata) if defined $adata;
+  $m->adata_add($adata) if defined $adata;
   my $ct = $m->encrypt_last($plaintext);
   my $tag = $m->encrypt_done;
   return ($ct, $tag);
@@ -37,15 +37,13 @@ sub ocb_decrypt_verify {
   my $tag = shift;
 
   my $m = Crypt::AuthEnc::OCB->new($cipher_name, $key, $nonce);
-  $m->aad_add($adata) if defined $adata;
+  $m->adata_add($adata) if defined $adata;
   my $ct = $m->decrypt_last($ciphertext);
   return $m->decrypt_done($tag) ? $ct : undef;
 }
 
-sub adata_add {
-  # obsolete, only for backwards compatibility
-  shift->aad_add(@_);
-}
+# obsolete, only for backwards compatibility
+sub aad_add { goto &adata_add }
 
 1;
 
@@ -62,8 +60,8 @@ Crypt::AuthEnc::OCB - Authenticated encryption in OCBv3 mode
 
  # encrypt and authenticate
  my $ae = Crypt::AuthEnc::OCB->new("AES", $key, $nonce);
- $ae->aad_add('additional_authenticated_data1');
- $ae->aad_add('additional_authenticated_data2');
+ $ae->adata_add('additional_authenticated_data1');
+ $ae->adata_add('additional_authenticated_data2');
  $ct = $ae->encrypt_add('data1');
  $ct = $ae->encrypt_add('data2');
  $ct = $ae->encrypt_add('data3');
@@ -72,8 +70,8 @@ Crypt::AuthEnc::OCB - Authenticated encryption in OCBv3 mode
 
  # decrypt and verify
  my $ae = Crypt::AuthEnc::OCB->new("AES", $key, $nonce);
- $ae->aad_add('additional_authenticated_data1');
- $ae->aad_add('additional_authenticated_data2');
+ $ae->adata_add('additional_authenticated_data1');
+ $ae->adata_add('additional_authenticated_data2');
  $pt = $ae->decrypt_add('ciphertext1');
  $pt = $ae->decrypt_add('ciphertext2');
  $pt = $ae->decrypt_add('ciphertext3');
@@ -125,9 +123,9 @@ You can export selected functions:
  # $key ..... AES key of proper length (128/192/256bits)
  # $nonce ... unique nonce/salt (no need to keep it secret)
 
-=head2 aad_add
+=head2 adata_add
 
- $ae->aad_add($adata);                          #can be called multiple times
+ $ae->adata_add($adata);                        #can be called multiple times
 
 =head2 encrypt_add
 
