@@ -959,22 +959,22 @@ int chacha_test(void);
 
 #endif /* LTC_CHACHA */
 
-#ifdef LTC_RC4
+#ifdef LTC_RC4_STREAM
 
 typedef struct {
-   int x, y;
+   unsigned int x, y;
    unsigned char buf[256];
 } rc4_state;
 
-int rc4_setup(rc4_state *st, const unsigned char *key, unsigned long keylen);
-int rc4_crypt(rc4_state *st, const unsigned char *in, unsigned long inlen, unsigned char *out);
-int rc4_keystream(rc4_state *st, unsigned char *out, unsigned long outlen);
-int rc4_done(rc4_state *st);
-int rc4_test(void);
+int rc4_stream_setup(rc4_state *st, const unsigned char *key, unsigned long keylen);
+int rc4_stream_crypt(rc4_state *st, const unsigned char *in, unsigned long inlen, unsigned char *out);
+int rc4_stream_keystream(rc4_state *st, unsigned char *out, unsigned long outlen);
+int rc4_stream_done(rc4_state *st);
+int rc4_stream_test(void);
 
-#endif /* LTC_RC4 */
+#endif /* LTC_RC4_STREAM */
 
-#ifdef LTC_SOBER128
+#ifdef LTC_SOBER128_STREAM
 
 typedef struct {
    ulong32 R[17],       /* Working storage for the shift register */
@@ -984,14 +984,14 @@ typedef struct {
    int     nbuf;        /* number of part-word stream bits buffered */
 } sober128_state;
 
-int sober128_setup(sober128_state *st, const unsigned char *key, unsigned long keylen);
-int sober128_setiv(sober128_state *st, const unsigned char *iv, unsigned long ivlen);
-int sober128_crypt(sober128_state *st, const unsigned char *in, unsigned long inlen, unsigned char *out);
-int sober128_keystream(sober128_state *st, unsigned char *out, unsigned long outlen);
-int sober128_done(sober128_state *st);
-int sober128_test(void);
+int sober128_stream_setup(sober128_state *st, const unsigned char *key, unsigned long keylen);
+int sober128_stream_setiv(sober128_state *st, const unsigned char *iv, unsigned long ivlen);
+int sober128_stream_crypt(sober128_state *st, const unsigned char *in, unsigned long inlen, unsigned char *out);
+int sober128_stream_keystream(sober128_state *st, unsigned char *out, unsigned long outlen);
+int sober128_stream_done(sober128_state *st);
+int sober128_stream_test(void);
 
-#endif /* LTC_SOBER128 */
+#endif /* LTC_SOBER128_STREAM */
 
 /* $Source$ */
 /* $Revision$ */
