@@ -22,14 +22,14 @@
    @param cipher   The index of the cipher desired
    @param key      The secret key
    @param keylen   The length of the secret key (octets)
-   @param filename The name of the file you wish to f9
+   @param fname    The name of the file you wish to f9
    @param out      [out] Where the authentication tag is to be stored
    @param outlen   [in/out] The max size and resulting size of the authentication tag
    @return CRYPT_OK if successful, CRYPT_NOP if file support has been disabled
 */
 int f9_file(int cipher,
               const unsigned char *key, unsigned long keylen,
-              const char *filename,
+              const char *fname,
                     unsigned char *out, unsigned long *outlen)
 {
 #ifdef LTC_NO_FILE
@@ -39,41 +39,50 @@ int f9_file(int cipher,
    int err;
    f9_state f9;
    FILE *in;
-   unsigned char buf[512];
+   unsigned char *buf;
 
-   LTC_ARGCHK(key      != NULL);
-   LTC_ARGCHK(filename != NULL);
-   LTC_ARGCHK(out      != NULL);
-   LTC_ARGCHK(outlen   != NULL);
+   LTC_ARGCHK(key    != NULL);
+   LTC_ARGCHK(fname  != NULL);
+   LTC_ARGCHK(out    != NULL);
+   LTC_ARGCHK(outlen != NULL);
 
-   in = fopen(filename, "rb");
-   if (in == NULL) {
-      return CRYPT_FILE_NOTFOUND;
+   if ((buf = XMALLOC(LTC_FILE_READ_BUFSIZE)) == NULL) {
+      return CRYPT_MEM;
    }
 
    if ((err = f9_init(&f9, cipher, key, keylen)) != CRYPT_OK) {
-      fclose(in);
-      return err;
+      goto LBL_ERR;
+   }
+
+   in = fopen(fname, "rb");
+   if (in == NULL) {
+      err = CRYPT_FILE_NOTFOUND;
+      goto LBL_ERR;
    }
 
    do {
-      x = fread(buf, 1, sizeof(buf), in);
+      x = fread(buf, 1, LTC_FILE_READ_BUFSIZE, in);
       if ((err = f9_process(&f9, buf, (unsigned long)x)) != CRYPT_OK) {
          fclose(in);
-         return err;
+         goto LBL_CLEANBUF;
       }
-   } while (x == sizeof(buf));
-   fclose(in);
+   } while (x == LTC_FILE_READ_BUFSIZE);
 
-   if ((err = f9_done(&f9,    out, outlen)) != CRYPT_OK) {
-      return err;
+   if (fclose(in) != 0) {
+      err = CRYPT_ERROR;
+      goto LBL_CLEANBUF;
    }
 
-#ifdef LTC_CLEAN_STACK
-   zeromem(buf, sizeof(buf));
-#endif
+   err = f9_done(&f9, out, outlen);
 
-   return CRYPT_OK;
+LBL_CLEANBUF:
+   zeromem(buf, LTC_FILE_READ_BUFSIZE);
+LBL_ERR:
+#ifdef LTC_CLEAN_STACK
+   zeromem(&f9, sizeof(f9_state));
+#endif
+   XFREE(buf);
+   return err;
 #endif
 }
 
